betty.serde package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.serde package

## Submodules

- betty.serde.dump module
  - `Dump`
  - `DumpMapping`
  - `DumpSequence`
  - `Dumpable`
    - `Dumpable.dump()`
  - `VoidableDump`
  - `VoidableDumpMapping`
  - `VoidableDumpSequence`
  - `minimize()`
  - `none_void()`
  - `void_none()`
- betty.serde.format module
  - `Format`
    - `Format.dump()`
    - `Format.extensions`
    - `Format.label`
    - `Format.load()`
  - `FormatError`
  - `FormatRepository`
    - `FormatRepository.__init__()`
    - `FormatRepository.extensions`
    - `FormatRepository.format_for()`
    - `FormatRepository.formats`
  - `FormatStr`
    - `FormatStr.__init__()`
    - `FormatStr.localize()`
  - `Json`
    - `Json.dump()`
    - `Json.extensions`
    - `Json.label`
    - `Json.load()`
  - `Yaml`
    - `Yaml.dump()`
    - `Yaml.extensions`
    - `Yaml.label`
    - `Yaml.load()`

## Module contents

Provide Betty’s serialization and deserialization API.